@@ -84,7 +84,7 @@ Plasma::QueryMatch SourcesModel::fetchMatch(int row) const
         }
     }
 
-    return Plasma::QueryMatch(0);
+    return Plasma::QueryMatch(nullptr);
 }
 
 QVariant SourcesModel::data(const QModelIndex& index, int role) const
@@ -224,36 +224,25 @@ void SourcesModel::setQueryString(const QString& str)
         return;
     }
 
+    m_modelPopulated = false;
+    m_manager->launchQuery(m_queryString, m_runner);
+
     // We avoid clearing the model instantly, and instead wait for the results
     // to show up, and only then do we clear the model. In the event
     // where there are no results, we wait for a predefined time before
     // clearing the model
     m_resetTimer.start();
-
-    m_modelPopulated = false;
-    m_manager->launchQuery(m_queryString, m_runner);
 }
 
 void SourcesModel::slotResetTimeout()
 {
     if (!m_modelPopulated) {
-        // The old items are still shown, get rid of them
-        beginResetModel();
-        m_matches.clear();
-        m_size = 0;
-        m_duplicates.clear();
-        endResetModel();
+        clear();
     }
 }
 
 void SourcesModel::slotMatchesChanged(const QList<Plasma::QueryMatch>& l)
 {
-    // We do reset handling ourselves, so ignore clears if the reset timer
-    // is supposed to handle them (see setQueryString)
-    if(l.length() == 0 && m_resetTimer.isActive() && !m_modelPopulated) {
-        return;
-    }
-
     beginResetModel();
     m_matches.clear();
     m_size = 0;
@@ -391,7 +380,7 @@ bool SourcesModel::run(int index)
         if (!info.isEmpty()) {
             // FIXME: pretty lame way to decide if this is a query prototype
             // Copied from kde4 krunner interface.cpp
-            if (match.runner() == 0) {
+            if (match.runner() == nullptr) {
                 // lame way of checking to see if this is a Help Button generated match!
                 int index = info.indexOf(QStringLiteral(":q:"));
 
